Class RqueueAutoStartupLifecycle

java.lang.Object
com.github.sonus21.rqueue.spring.boot.RqueueAutoStartupLifecycle
All Implemented Interfaces:
EventListener, org.springframework.beans.factory.config.BeanPostProcessor, org.springframework.context.ApplicationListener<org.springframework.boot.context.event.ApplicationReadyEvent>

public class RqueueAutoStartupLifecycle extends Object implements org.springframework.beans.factory.config.BeanPostProcessor, org.springframework.context.ApplicationListener<org.springframework.boot.context.event.ApplicationReadyEvent>
Delays Rqueue poller startup in Boot web applications until the servlet or reactive web server is ready and Spring Boot has published ApplicationReadyEvent.
  • Constructor Details

    • RqueueAutoStartupLifecycle

      public RqueueAutoStartupLifecycle()
  • Method Details

    • delayAutoStartup

      public void delayAutoStartup(com.github.sonus21.rqueue.listener.RqueueMessageListenerContainer container)
    • postProcessBeforeInitialization

      public Object postProcessBeforeInitialization(Object bean, String beanName) throws org.springframework.beans.BeansException
      Specified by:
      postProcessBeforeInitialization in interface org.springframework.beans.factory.config.BeanPostProcessor
      Throws:
      org.springframework.beans.BeansException
    • onApplicationEvent

      public void onApplicationEvent(org.springframework.boot.context.event.ApplicationReadyEvent event)
      Specified by:
      onApplicationEvent in interface org.springframework.context.ApplicationListener<org.springframework.boot.context.event.ApplicationReadyEvent>