Package com.github.sonus21.rqueue.spring.boot
package com.github.sonus21.rqueue.spring.boot
-
ClassesClassDescriptionDelays Rqueue poller startup in Boot web applications until the servlet or reactive web server is ready and Spring Boot has published
ApplicationReadyEvent.Auto-configuration that wires a JetStream-backedMessageBrokerwhenrqueue.backend=natsand the jnats client is on the classpath.Post-listener auto-configuration that wires the NATS-backed worker registry afterRqueueListenerAutoConfighas run and theRqueueConfigbean is available.Configuration properties for the optional NATS / JetStream backend.Conditionally importsRqueueRedisListenerConfigonly when therqueue-redismodule is on the classpath.